@@ -78,10 +78,10 @@ function _aws_cdk_aws_sns_Subscription(p) {
 }
 function _aws_cdk_aws_sns_Topic(p) {
 }
-function _aws_cdk_aws_sns_SubscriptionFilter(p) {
-}
 function _aws_cdk_aws_sns_CfnTopicPolicy(p) {
 }
+function _aws_cdk_aws_sns_SubscriptionFilter(p) {
+}
 function _aws_cdk_aws_sns_CfnSubscription(p) {
 }
 function _aws_cdk_aws_sns_CfnTopicProps(p) {
@@ -115,5 +115,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_sns_SubscriptionProtocol, _aws_cdk_aws_sns_BetweenCondition, _aws_cdk_aws_sns_CfnTopicPolicyProps, _aws_cdk_aws_sns_StringConditions, _aws_cdk_aws_sns_TopicProps, _aws_cdk_aws_sns_CfnSubscriptionProps, _aws_cdk_aws_sns_SubscriptionProps, _aws_cdk_aws_sns_TopicSubscriptionConfig, _aws_cdk_aws_sns_TopicPolicyProps, _aws_cdk_aws_sns_ITopicSubscription, _aws_cdk_aws_sns_NumericConditions, _aws_cdk_aws_sns_SubscriptionOptions, _aws_cdk_aws_sns_TopicPolicy, _aws_cdk_aws_sns_Subscription, _aws_cdk_aws_sns_Topic, _aws_cdk_aws_sns_SubscriptionFilter, _aws_cdk_aws_sns_CfnTopicPolicy, _aws_cdk_aws_sns_CfnSubscription, _aws_cdk_aws_sns_CfnTopicProps, _aws_cdk_aws_sns_CfnTopic, _aws_cdk_aws_sns_CfnTopic_SubscriptionProperty, _aws_cdk_aws_sns_ITopic, _aws_cdk_aws_sns_TopicBase };
+module.exports = { print, _aws_cdk_aws_sns_SubscriptionProtocol, _aws_cdk_aws_sns_BetweenCondition, _aws_cdk_aws_sns_CfnTopicPolicyProps, _aws_cdk_aws_sns_StringConditions, _aws_cdk_aws_sns_TopicProps, _aws_cdk_aws_sns_CfnSubscriptionProps, _aws_cdk_aws_sns_SubscriptionProps, _aws_cdk_aws_sns_TopicSubscriptionConfig, _aws_cdk_aws_sns_TopicPolicyProps, _aws_cdk_aws_sns_ITopicSubscription, _aws_cdk_aws_sns_NumericConditions, _aws_cdk_aws_sns_SubscriptionOptions, _aws_cdk_aws_sns_TopicPolicy, _aws_cdk_aws_sns_Subscription, _aws_cdk_aws_sns_Topic, _aws_cdk_aws_sns_CfnTopicPolicy, _aws_cdk_aws_sns_SubscriptionFilter, _aws_cdk_aws_sns_CfnSubscription, _aws_cdk_aws_sns_CfnTopicProps, _aws_cdk_aws_sns_CfnTopic, _aws_cdk_aws_sns_CfnTopic_SubscriptionProperty, _aws_cdk_aws_sns_ITopic, _aws_cdk_aws_sns_TopicBase };
 module.exports.DeprecationError = DeprecationError;
